@@ -24,12 +24,13 @@ class CSVFile(CSVdefault):
         """
         """
         f = obj.Schema().getField(field).get(obj)
-        if f is None:
+        if not f :
             return ''
         else:
             filename = f.filename
             if zip is not None:
-                if obj.Schema().getField(field).getType()=="plone.app.blob.subtypes.file.ExtensionBlobField":
+                logger.error(obj.Schema().getField(field).getType())
+                if obj.Schema().getField(field).getType() in ("plone.app.blob.subtypes.file.ExtensionBlobField", "Products.Archetypes.Field.ImageField"):
                     f=f.data
                 zip.writestr(filename, f)
             return filename
@@ -45,5 +46,4 @@ class CSVFile(CSVdefault):
                 obj.Schema().getField(field).get(obj).setFilename(value)
             else:
                 raise csvreplicataPermissionException, "Insufficient privileges to modify this object and/or field"
-        
         
\ No newline at end of file
